@@ -8,6 +8,7 @@ use base qw{Class::Accessor};
 
 use Elive;
 use Elive::Entity;
+use Elive::Util;
 
 =head1 NAME
 
@@ -148,22 +149,26 @@ sub call {
 
     $params{adapter} ||= 'default';
 
-    my @soap_params = (SOAP::Data->name('_')->uri('')->value(''),
-		       SOAP::Header->type(xml => $self->_soap_header_xml()),
-		       SOAP::Data->name('command')->value($cmd),
+    my @soap_params = (
+	(SOAP::Data
+	 ->name('request')
+	 ->uri('http://www.soapware.org')
+	 ->prefix('m')
+	 ->value('')),
+	 SOAP::Header->type(xml => $self->_soap_header_xml()),
+	 SOAP::Data->name('command')->value($cmd),
 	);
 
     foreach my $name (keys %params) {
 
 	my $value = $params{$name};
 
-	$value = SOAP::Data->type(string => $value)
+	$value = SOAP::Data->type(string => Elive::Util::string($value))
 	    unless UNIVERSAL::isa($value, 'SOAP::Data');
 
 	my $soap_param = $value->name($name);
 
 	push (@soap_params, $soap_param);
-
     }
 
     my $som = $self->soap->call( @soap_params );
