@@ -11,11 +11,10 @@ use YAML;
 
 BEGIN {
     __PACKAGE__->mk_classdata('_entities' => {});
-    __PACKAGE__->mk_classdata('_collections' => {});
     __PACKAGE__->mk_classdata('_aliases');
     __PACKAGE__->mk_classdata('_entity_name');
     __PACKAGE__->mk_classdata('_primary_key', []);
-    __PACKAGE__->mk_classdata('_collection_name');
+    __PACKAGE__->mk_classdata('collection_name');
     __PACKAGE__->mk_classdata('isa');
 };
 
@@ -123,26 +122,7 @@ sub entity_name {
 
 =cut
 
-sub collection_name {
-    my $entity_class = shift;
-
-    if (my $collection_name = shift) {
-
-	#
-	# Set our entity name. Register it in our parent
-	#
-	$entity_class->_collection_name(ucfirst($collection_name));
-
-	my $collections = $entity_class->_collections;
-
-	die "Entity $collection_name redeclared "
-	    if exists $collections->{$collection_name};
-
-	$collections->{lcfirst($collection_name)} = $entity_class;
-    }
-
-    return $entity_class->_collection_name;
-}
+# Class::Data::Inheritable property
 
 # _alias, _get_aliases
 #
@@ -252,20 +232,6 @@ sub entities {
     return $entity_class->_entities;
 }
 
-=head2 collections
-
-    my $collections = Entity::Entity->collections;
-
-Return has hash ref of entities that have pluralised names.
-
-=cut
-
-sub collections {
-    my $entity_class = shift;
-
-    return $entity_class->_collections;
-}
-
 sub _ordered_attribute_names {
     my $class = shift;
 
